@@ -16,24 +16,24 @@ def action(ns, series, episodes):
             series, episode['season_number'], episode['episode_number'])
 
         if is_watched and not ns.unmark:
-            print ns.term.bold_red(u"already marked: {0}".format(name))
+            print ns.t.bold_red(u"already marked: {0}".format(name))
             continue
 
         if not is_watched and ns.unmark:
-            print ns.term.bold_red(u"not marked: {0}".format(name))
+            print ns.t.bold_red(u"not marked: {0}".format(name))
             continue
 
         ns.series.set_episode_watched(episode, (not ns.unmark))
 
         if not ns.unmark:
-            print ns.term.bold_green(u"marked: {0}".format(name))
+            print ns.t.bold_green(u"marked: {0}".format(name))
         else:
-            print ns.term.bold_green(u"unmarked: {0}".format(name))
+            print ns.t.bold_green(u"unmarked: {0}".format(name))
 
         changed += 1
 
     if changed == 0:
-        print ns.term.bold_red(u"did not change any episodes")
+        print ns.t.bold_red(u"did not change any episodes")
         return 1
 
     return 0
