@@ -2,24 +2,24 @@ from ..format import print_series
 
 
 def action(ns):
-    print ns.term.bold_magenta(u"Results from searching online database")
+    print ns.t.bold_magenta(u"Results from searching online database")
     print u""
 
     if not ns.synced:
-        print ns.term.bold_red("Application not synced")
+        print ns.t.bold_red("Application not synced")
         return 1
 
     series = ns.api.getseries(ns.query)
 
     if not series:
-        print ns.term.bold_red("No series matching '{0}'".format(ns.query))
+        print ns.t.bold_red("No series matching '{0}'".format(ns.query))
         return 1
 
     if ns.limit:
         series = series[:ns.limit]
 
     for s in series:
-        print_series(ns.term, s)
+        print_series(ns.t, s)
 
 
 def setup(parser):
