@@ -1,6 +1,12 @@
 import contextlib
 import json
 import os
+import collections
+
+
+DictStorageStats = collections.namedtuple(
+    "DictStorageStats",
+    ['clears', 'deletions', 'noops'])
 
 
 class Block(object):
@@ -16,20 +22,23 @@ class Block(object):
     def dump_key(self, key):
         return key
 
+    def dump_header(self, fd):
+        raise NotImplementedError("dump_header")
+
+    def load_header(self, fd):
+        raise NotImplementedError("load_header")
+
     def write_header(self, fd):
         raise NotImplementedError("write_header")
 
-    def read_header(self, fd):
-        raise NotImplementedError("read_header")
-
     def load_item(self, i):
         raise NotImplementedError("load_item")
 
     def write_entry(self, fd, op, key, value):
         raise NotImplementedError("write_entry")
 
-    def parse_entry(self, line):
-        raise NotImplementedError("parse_entry")
+    def load_entry(self, line):
+        raise NotImplementedError("load_entry")
 
 
 class JSONValueBlock(object):
@@ -53,13 +62,17 @@ class JSONValueBlock(object):
 
 
 class StandardHeader(object):
-    def write_header(self, fd):
-        fd.write("version={0}".format(self.VERSION) + self.DELIM)
+    def dump_header(self, d):
+        return " ".join("=".join(i) for i in d.items())
 
-    def read_header(self, fd):
-        v = fd.readline()
-        v = v.strip()
-        return dict(s.split("=", 1) for s in v.split(" "))
+    def load_header(self, s):
+        if not s:
+            return None
+
+        return dict(s.split("=", 1) for s in s.split(" "))
+
+    def write_header(self, fd):
+        fd.write(self.dump_header(self.header()))
 
 
 class V1Block(JSONValueBlock, StandardHeader, Block):
@@ -70,6 +83,9 @@ class V1Block(JSONValueBlock, StandardHeader, Block):
     def __init__(self, encoding='utf-8'):
         self._encoding = encoding
 
+    def header(self):
+        return "version={0}".format(self.VERSION) + self.DELIM
+
     def load_item(self, i):
         key, value = i
         return (self.load_key(key), self.load_value(value))
@@ -81,7 +97,7 @@ class V1Block(JSONValueBlock, StandardHeader, Block):
         entry = self.SPACE.join((op, key_length, key, value)) + self.DELIM
         fd.write(entry)
 
-    def parse_entry(self, line):
+    def load_entry(self, line):
         op, key_length, b = line.split(self.SPACE, 2)
         key_length = int(key_length)
         key = b[:key_length].decode(self._encoding)
@@ -100,7 +116,7 @@ class BlockYielder(object):
 
         try:
             for line in self._fd:
-                op, key, value = self._block.parse_entry(line)
+                op, key, value = self._block.load_entry(line)
                 key = self._block.load_key(key)
                 yield op, key, value
         finally:
@@ -116,6 +132,8 @@ class FilesystemDriver(object):
         V1Block.VERSION: V1Block,
     }
 
+    default_version = V1Block.VERSION
+
     def __init__(self, path, driver_open=open, encoding='utf-8'):
         self._path = path
         self._compact_path = os.path.join(
@@ -146,9 +164,14 @@ class FilesystemDriver(object):
                 self._block.write_entry(fd, op, key, value)
 
     def createyielder(self):
-        fd = self._driver_open(self._path, 'r')
+        fd = self._driver_open(self._path, 'a+')
 
-        header = self._block.read_header(fd)
+        header_line = fd.readline()
+
+        if header_line:
+            header = self._block.load_header(header_line.strip())
+        else:
+            header = dict(version=self.default_version)
 
         # setup temporary block format for reading.
         # this is useful for migrating old database formats behind the scenes.
@@ -175,30 +198,29 @@ class DictStorage(object):
     # clear the entire data set.
     CLEAR = "X"
 
-    def __init__(self, path, driver):
-        self._path = path
-        self._log = list()
+    def __init__(self, driver):
         self._driver = driver
-        self._statistics = dict()
+        self._log = list()
+        self._stats = None
 
-    def open(self):
-        cache = self._read_cache(self._driver.createyielder())
-        return cache, self._statistics
+    def read(self):
+        self._stats, data = self._read_cache(self._driver.createyielder())
+        return data
 
-    def statistics(self):
-        return self._statistics
+    def stats(self):
+        return self._stats
 
     def _read_cache(self, yielder):
         data = dict()
 
         # generate statistics to decide if we should autocompact the database.
         clears = 0
-        removes = 0
+        deletions = 0
 
         for op, key, value in yielder.readblocks():
             if op == self.DELETION:
-                data.pop(key, None)
-                removes += 1
+                del data[key]
+                deletions += 1
                 continue
 
             if op == self.CLEAR:
@@ -212,13 +234,14 @@ class DictStorage(object):
 
             raise Exception("unknown operation '{0}'".format(op))
 
-        self._statistics = {
-            "clears": clears,
-            "removes": removes,
-            "nops": removes + clears,
-        }
+        data = dict(yielder.load_item(i) for i in data.items())
 
-        return dict(yielder.load_item(i) for i in data.items())
+        stats = DictStorageStats(
+            clears=clears,
+            deletions=deletions,
+            noops=deletions + clears)
+
+        return stats, data
 
     def commit(self):
         self._driver.appendlog(self._log)
@@ -238,15 +261,12 @@ class DictStorage(object):
 
         self._driver.compact(generator)
 
-        statistics = self._statistics
+        stats = self._stats
 
-        self._statistics = {
-            'clears': 0,
-            'removes': 0,
-            'nops': 0,
-        }
+        self._stats = DictStorageStats(
+            clears=0, deletions=0, noops=0)
 
-        return statistics
+        return stats
 
     def db_size(self):
         return self._driver.db_size()
@@ -281,10 +301,12 @@ class DictDB(dict):
         raise NotImplementedError("update")
 
     def popitem(self, **args):
-        raise NotImplementedError("popitem")
+        key, value = dict.popitem(self)
+        self._storage.delitem(key)
+        return key, value
 
     def list_append(self, key, data):
-        array = list(self.get(key, []))
+        array = self.get(key, [])
         array.append(data)
         self.__setitem__(key, array)
 
@@ -338,18 +360,20 @@ def open_database(
 ):
     driver_instance = driver(path, driver_open=driver_open)
 
-    storage = DictStorage(path, driver_instance)
+    storage = DictStorage(driver_instance)
 
-    cache, statistics = storage.open()
+    cache = storage.read()
+
+    stats = storage.stats()
 
     db = impl(storage, cache)
 
-    # nops means non-operations, basically operations that does not contribute
+    # noops means non-operations, basically operations that does not contribute
     # to the final structure of the data.
     #
     # if we hit a limit here, we should cleanup, otherwise it's a waste of
     # space.
-    if statistics['nops'] > compaction_limit:
+    if stats.noops > compaction_limit:
         db.compact()
 
     yield db
